/*
 * CalendarDate.java
 */

package scheduler.domain;

import java.sql.Date;
import java.util.*;
import scheduler.util.*;

public class CalendarDate
{
	private Scheduler scheduler;
	private Date date;
	private int dayOfMonth;
	private int dayOfWeek;

	// List<Schedule>
	private List    schedules    = null;
	private Boolean hasSchedules = null;

	public CalendarDate(Scheduler scheduler, Date date) {
		this(scheduler, date, DateTimeUtils.getDay(date));
	}

	public CalendarDate(Scheduler scheduler, int year, int month, int day) {
		this(scheduler, DateTimeUtils.toSQLDate(year, month, day), day);
	}

	private CalendarDate(Scheduler scheduler, Date date, int dayOfMonth) {
		this.scheduler  = scheduler;
		this.date       = date;
		this.dayOfMonth = dayOfMonth;
		this.dayOfWeek  = DateTimeUtils.getDayOfWeek(date);
	}

	public Date getDate() {
		return date;
	}

	public int getYear() {
		return DateTimeUtils.getYear(date);
	}

	public int getMonth() {
		return DateTimeUtils.getMonth(date);
	}

	public int getDay() {
		return dayOfMonth;
	}

	public int getDayOfWeek() {
		return dayOfWeek;
	}

	public boolean hasSchedules() {
		// LbV`FbN.
		if (hasSchedules != null) {
			return hasSchedules.booleanValue();
		}
		// Œ肵\肪邩?
		ScheduleList fixed = scheduler.getFixedSchedules(date);
		if (fixed.hasValids(date)) {
			hasSchedules = Boolean.TRUE;
			return true;
		}
		// T̗\肪邩?
		ScheduleList weekly = scheduler.getWeeklySchedules(dayOfWeek);
		if (weekly.hasValids(date)) {
			hasSchedules = Boolean.TRUE;
			return true;
		}
		// Ȃꍇ.
		hasSchedules = Boolean.FALSE;
		return false;
	}

	static final Comparator scheduleCmp = new Comparator() {
		public int compare(Object o1, Object o2) {
			Schedule s1 = (Schedule)o1;
			Schedule s2 = (Schedule)o2;
			int cmp = s1.getTime().compareTo(s2.getTime());
			if (cmp != 0) return cmp;
			Content c1 = s1.getContent();
			Content c2 = s2.getContent();
			return c1.getMemo().compareTo(c2.getMemo());
		}
	};

	public List getSchedules() {
		// LbV`FbN.
		if (schedules != null) return schedules;
		// Œ肵\W߂.
		ScheduleList fixed = scheduler.getFixedSchedules(date);
		List list = new ArrayList(fixed.getAll());
		// T̗\W߂.
		ScheduleList weekly = scheduler.getWeeklySchedules(dayOfWeek);
		for (Iterator i = weekly.getAll().iterator(); i.hasNext(); ) {
			WeeklySchedule schedule = (WeeklySchedule)i.next();
			if (schedule.isValid(date)) {
				list.add(schedule);
			}
		}
		// Ƀ\[g.
		Collections.sort(list, scheduleCmp);
		// LbVݒ肷.
		schedules = list;
		hasSchedules = schedules.isEmpty() ? Boolean.FALSE : Boolean.TRUE;
		return schedules;
	}

	public void addFixedSchedule(FixedSchedule schedule) {
		if (!schedule.isValid(date)) {
			throw new IllegalArgumentException(schedule.toString());
		}
		scheduler.addFixedSchedule(schedule);
		hasSchedules = Boolean.TRUE;
		if (schedules == null) return;
		// LbVXV.
		int index = Collections.binarySearch(schedules, schedule, scheduleCmp);
		if (index < 0) index = -1 - index;
		schedules.add(index, schedule);
	}

	public void removeFixedSchedule(FixedSchedule schedule) {
		if (!schedule.isValid(date)) {
			throw new IllegalArgumentException(schedule.toString());
		}
		scheduler.removeFixedSchedule(schedule);
		if (schedules == null) {
			hasSchedules = null;
			return;
		}
		// LbVXV.
		int index = Collections.binarySearch(schedules, schedule, scheduleCmp);
		if (index >= 0) {
			schedules.remove(index);
			if (schedules.isEmpty()) hasSchedules = Boolean.FALSE;
		}
	}

	public void resetSchedules() {
		if (schedules != null) {
			schedules.clear();
			schedules = null;
		}
		hasSchedules = null;
	}

	static final String LINE_SEPARATOR = System.getProperty("line.separator");

	public String toString() {
		StringBuffer buf = new StringBuffer();
		buf.append('[').append(date).append(']');
		if (schedules == null) {
			buf.append(LINE_SEPARATOR).append("...");
		} else {
			for (Iterator i = schedules.iterator(); i.hasNext(); ) {
				buf.append(LINE_SEPARATOR).append(i.next());
			}
		}
		return buf.toString();
	}
}
