/*
 * WeeklySchedule.java
 */

package scheduler.domain;

import java.sql.Date;
import java.sql.Time;
import java.util.Calendar;
import scheduler.util.DateTimeUtils;

public class WeeklySchedule extends RepeatedSchedule
{
	private int dayOfWeek;

	public WeeklySchedule(int dayOfWeek, Time time, String memo) {
		super(time, memo);
		this.dayOfWeek = dayOfWeek;
	}

	public WeeklySchedule(int dayOfWeek, int hour, int minute, String memo) {
		this(dayOfWeek, DateTimeUtils.toSQLTime(hour, minute, 0), memo);
	}

	public int getDayOfWeek() {
		return dayOfWeek;
	}

	public boolean isValid(Date date) {
		if (!includes(date)) return false;
		return DateTimeUtils.getDayOfWeek(date) == dayOfWeek;
	}

	static final String[] dayOfWeekText
		= { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" };

	public String toString() {
		StringBuffer buf = new StringBuffer();
		buf.append(super.toString());
		buf.append(" (");
		buf.append(dayOfWeekText[dayOfWeek - Calendar.SUNDAY]);
		String range = getRangeString();
		if (range.length() > 0) {
			buf.append("; ");
			buf.append(range);
		}
		buf.append(")");
		return buf.toString();
	}
}
