/*
 * CalendarFrame.java
 */

package scheduler.gui;

import java.awt.*;
import java.awt.event.*;
import java.text.DateFormatSymbols;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.table.TableModel;
import scheduler.domain.*;

public class CalendarFrame extends JFrame
{
	static final ResourceBundle resources
			= ResourceBundle.getBundle("scheduler/resources/scheduler");

	static final String[] monthNames
			= new DateFormatSymbols().getMonths();

	private Scheduler scheduler;

	private JComboBox   yearsComboBox;
	private JTabbedPane monthsTabbedPane;

	public CalendarFrame(Scheduler scheduler) {
		super(resources.getString("frame.calendar"));
		this.scheduler = scheduler;
		getContentPane().add(makePanel());
		setSize(new Dimension(400, 196));	// _~[B
		setResizable(false);
		enableEvents(AWTEvent.WINDOW_EVENT_MASK);
	}

	private JPanel makePanel() {
		JPanel panel = new JPanel();
		panel.setLayout(new BorderLayout());
		Calendar calendar = Calendar.getInstance();
		int thisYear  = calendar.get(Calendar.YEAR);
		int thisMonth = calendar.get(Calendar.MONTH) + 1;
		panel.add(makeYearsComboBox(thisYear), BorderLayout.NORTH);
		panel.add(makeMonthsTabbedPane(thisYear, thisMonth),
				BorderLayout.CENTER);
		return panel;
	}

	private JComboBox makeYearsComboBox(int thisYear) {
		// Xg\݂͌̔N + 5NƂB
		yearsComboBox = new JComboBox();
		for (int i = 0; i < 5; ++i) {
			yearsComboBox.addItem(Integer.toString(thisYear + i));
		}
		yearsComboBox.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				yearsComboBox_actionPerformed(e);
			}
		});
		return yearsComboBox;
	}

	private JTabbedPane makeMonthsTabbedPane(int thisYear, int thisMonth) {
		monthsTabbedPane = new JTabbedPane();
		updateMonthsTabbedPane(thisYear);
		monthsTabbedPane.setSelectedIndex(thisMonth - 1);
		return monthsTabbedPane;
	}

	private void updateMonthsTabbedPane(int year) {
		monthsTabbedPane.removeAll();
		// 12B
		for (int month = 1; month <= 12; ++month) {
			TableModel model = new MonthTableModel(scheduler, year, month);
			JTable table = new MonthTable(model);
			table.addMouseListener(new MouseAdapter() {
				public void mouseClicked(MouseEvent e) {
					table_mouseClicked(e);
				}
			});
			monthsTabbedPane.add(new JScrollPane(table), monthNames[month - 1]);
		}
	}

	private void exit() {
		try {
			scheduler.save();
		} catch (Exception e) {
			e.printStackTrace();
		}
		System.exit(0);
	}

	void table_mouseClicked(MouseEvent e) {
		JTable table = (JTable)e.getSource();
		int row    = table.rowAtPoint(e.getPoint());
		int column = table.columnAtPoint(e.getPoint());
		TableModel model = table.getModel();
		DateCell dateCell = (DateCell)model.getValueAt(row, column);
		CalendarDate date = dateCell.getCalendarDate();
		if (date == null) return;

		if (date.hasSchedules()) {
			new DateScheduleDialog(this, date).show();
		} else {
			new RegisterDialog(this, date).show();
		}
		model.setValueAt(dateCell, row, column);
		monthsTabbedPane.getSelectedComponent().setVisible(true);
	}

	void yearsComboBox_actionPerformed(ActionEvent e) {
		String s = (String)yearsComboBox.getSelectedItem();
		int year = Integer.parseInt(s);
		updateMonthsTabbedPane(year);
	}

	protected void processWindowEvent(WindowEvent e) {
		super.processWindowEvent(e);
		if (e.getID() == WindowEvent.WINDOW_CLOSING) {
			exit();
		}
	}
}
