/*
 * DateScheduleDialog.java
 */

package scheduler.gui;

import java.awt.*;
import java.awt.event.*;
import java.sql.Date;
import java.sql.Time;
import java.util.*;
import java.util.List;
import javax.swing.*;
import scheduler.domain.*;
import scheduler.util.*;

public class DateScheduleDialog extends JDialog
{
	static final ResourceBundle resources
		= ResourceBundle.getBundle("scheduler/resources/scheduler");

	private CalendarDate calendarDate;

	private JButton addButton;
	private JButton editButton;
	private JButton removeButton;
	private JList   schedulesList;

	static class Line {
		private Schedule schedule;
		public Line(Schedule schedule) {
			this.schedule = schedule;
		}
		public Schedule getSchedule() {
			return schedule;
		}
		public String toString() {
			return DateTimeFormat.formatH2M2(schedule.getTime())
					+ ' ' + schedule.getContent();
		}
	}

	public DateScheduleDialog(Frame frame, CalendarDate date) {
		super(frame, DateTimeFormat.formatY4M2D2(date.getDate()), true);
		this.calendarDate = date;
		getContentPane().add(makePanel());
		pack();
	}

	private JPanel makePanel() {
		JPanel panel = new JPanel();
		panel.setLayout(new GridBagLayout());
		GridBagConstraints gbc = new GridBagConstraints(
				0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER,
				GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0);
		panel.add(makeAddButton(), gbc);
		gbc.gridx = 1;
		panel.add(makeEditButton(), gbc);
		gbc.gridx = 2;
		panel.add(makeRemoveButton(), gbc);
		gbc.gridx = 0; gbc.gridy = 1; gbc.gridwidth = 3;
		gbc.fill = GridBagConstraints.BOTH;
		panel.add(new JScrollPane(makeSchedulesList()), gbc);
		return panel;
	}

	private JButton makeAddButton() {
		addButton = new JButton(resources.getString("button.add"));
		addButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				addButton_actionPerformed(e);
			}
		});
		return addButton;
	}

	private JButton makeEditButton() {
		editButton = new JButton(resources.getString("button.edit"));
		editButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				editButton_actionPerformed(e);
			}
		});
		return editButton;
	}

	private JButton makeRemoveButton() {
		removeButton = new JButton(resources.getString("button.remove"));
		removeButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				removeButton_actionPerformed(e);
			}
		});
		return removeButton;
	}

	private JList makeSchedulesList() {
		schedulesList = new JList();
		// I sB
		schedulesList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		schedulesList.addMouseListener(new MouseAdapter() {
			public void mouseClicked(MouseEvent e) {
				schedulesList_mouseClicked(e);
			}
		});
		updateSchedulesList();
		return schedulesList;
	}

	private void updateSchedulesList() {
		DefaultListModel model = new DefaultListModel();
		List schedules = calendarDate.getSchedules();
		for (Iterator i = schedules.iterator(); i.hasNext(); ) {
			Schedule schedule = (Schedule)i.next();
			model.addElement(new Line(schedule));
		}
		schedulesList.setModel(model);
	}

	private void editSchedule() {
		Line line = (Line)schedulesList.getSelectedValue();
		FixedSchedule schedule = (FixedSchedule)line.getSchedule();
		new RegisterDialog(this, calendarDate, schedule).show();
		updateSchedulesList();
	}

	void addButton_actionPerformed(ActionEvent e) {
		new RegisterDialog(this, calendarDate, null).show();
		updateSchedulesList();
	}

	void editButton_actionPerformed(ActionEvent e) {
		if (schedulesList.getSelectedIndex() < 0) return;
		editSchedule();
	}

	void removeButton_actionPerformed(ActionEvent e) {
		Line line = (Line)schedulesList.getSelectedValue();
		FixedSchedule schedule = (FixedSchedule)line.getSchedule();
		calendarDate.removeFixedSchedule(schedule);
		if (calendarDate.hasSchedules()) {
			updateSchedulesList();
		} else {
			dispose();
		}
	}

	void schedulesList_mouseClicked(MouseEvent e) {
		if (e.getClickCount() != 2) return;
		JList list = (JList)e.getComponent();
		int index = list.locationToIndex(e.getPoint());
		if (index < 0) return;
		int selectedIndex = list.getSelectedIndex();
		if (index != selectedIndex) return;
		editSchedule();
	}
}
