/*
 * MonthTableModel.java
 */

package scheduler.gui;

import java.sql.Date;
import java.text.DateFormatSymbols;
import java.util.Calendar;
import javax.swing.event.TableModelEvent;
import javax.swing.table.AbstractTableModel;
import scheduler.domain.*;
import scheduler.util.DateTimeUtils;

public class MonthTableModel extends AbstractTableModel
{
	static final int ROW_COUNT    = 6;
	static final int COLUMN_COUNT = 7;

	static final String[] weekdayNames
			= new DateFormatSymbols().getShortWeekdays();

	private Scheduler     scheduler;
	private CalendarMonth calendarMonth;
	private DateCell[][]  dateCells;

	public MonthTableModel(Scheduler scheduler, int year, int month) {
		this.scheduler = scheduler;

		// 1̗j߂B
		Date date = DateTimeUtils.toSQLDate(year, month, 1);
		int dayOfWeek = DateTimeUtils.getDayOfWeek(date);

		calendarMonth = new CalendarMonth(scheduler, year, month);
		CalendarDate[] dates = calendarMonth.getDates();
		dateCells = new DateCell[ROW_COUNT][];
		int index = Calendar.SUNDAY - dayOfWeek;
		for (int i = 0; i < ROW_COUNT; ++i) {
			dateCells[i] = new DateCell[COLUMN_COUNT];
			for (int j = 0; j < COLUMN_COUNT; ++j) {
				CalendarDate calendarDate = null;
				if (0 <= index && index < dates.length) {
					calendarDate = dates[index];
				}
				dateCells[i][j] = new DateCell(calendarDate);
				++index;
			}
		}
	}

	public int getRowCount() {
		return ROW_COUNT;
	}

	public int getColumnCount() {
		return COLUMN_COUNT;
	}

	public String getColumnName(int column) {
		return weekdayNames[column + Calendar.SUNDAY];
	}

	public Class getColumnClass(int column) {
		return DateCell.class;
	}

	public Object getValueAt(int row, int column) {
		return dateCells[row][column];
	}
}
