/*
 * RegisterDialog.java
 */

package scheduler.gui;

import java.awt.*;
import java.awt.event.*;
import java.sql.Date;
import java.sql.Time;
import java.util.ResourceBundle;
import javax.swing.*;
import scheduler.domain.*;
import scheduler.util.*;

public class RegisterDialog extends JDialog
{
	static final ResourceBundle resources
			= ResourceBundle.getBundle("scheduler/resources/scheduler");

	private CalendarDate  calendarDate;
	private FixedSchedule fixedSchedule;

	private JComboBox  hoursComboBox;
	private JComboBox  minutesComboBox;
	private JTextField memoTextField;
	private JButton    registerButton;

	public RegisterDialog(Dialog dialog,
			CalendarDate date, FixedSchedule schedule) {
		super(dialog, DateTimeFormat.formatY4M2D2(date.getDate()), true);
		this.calendarDate  = date;
		this.fixedSchedule = schedule;
		getContentPane().add(makePanel());
		pack();
		if (schedule != null) {
			hoursComboBox.setSelectedIndex(schedule.getHour());
			minutesComboBox.setSelectedIndex(schedule.getMinute());
			memoTextField.setText(schedule.getContent().getMemo());
		}
	}

	public RegisterDialog(Frame frame, CalendarDate date) {
		super(frame, DateTimeFormat.formatY4M2D2(date.getDate()), true);
		this.calendarDate  = date;
		this.fixedSchedule = null;
		getContentPane().add(makePanel());
		pack();
	}

	private JPanel makePanel() {
		JPanel panel = new JPanel();
		panel.setLayout(new GridBagLayout());
		GridBagConstraints gbc = new GridBagConstraints(
				0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER,
				GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0);
		panel.add(makeHoursComboBox(), gbc);
		gbc.gridx = 1; gbc.anchor = GridBagConstraints.WEST;
		panel.add(new JLabel(resources.getString("label.hour")), gbc);
		gbc.gridx = 2; gbc.anchor = GridBagConstraints.CENTER;
		panel.add(makeMinutesComboBox(), gbc);
		gbc.gridx = 3; gbc.anchor = GridBagConstraints.WEST;
		panel.add(new JLabel(resources.getString("label.minute")), gbc);
		memoTextField = new JTextField();
		memoTextField.setPreferredSize(new Dimension(200, 21));
		gbc.gridx = 0; gbc.gridy = 1; gbc.gridwidth = 4;
		gbc.anchor = GridBagConstraints.CENTER;
		panel.add(memoTextField, gbc);
		gbc.gridx = 3; gbc.gridy = 2; gbc.gridwidth = 1;
		gbc.insets.top = 10;
		gbc.anchor = GridBagConstraints.EAST;
		panel.add(makeRegisterButton(), gbc);
		return panel;
	}

	private JComboBox makeHoursComboBox() {
		hoursComboBox = new JComboBox();
		hoursComboBox.setPreferredSize(new Dimension(50, 21));
		for (int i = 0; i < 24; ++i) {
			hoursComboBox.addItem(Integer.toString(i));
		}
		return hoursComboBox;
	}

	private JComboBox makeMinutesComboBox() {
		minutesComboBox = new JComboBox();
		minutesComboBox.setPreferredSize(new Dimension(50, 21));
		for (int i = 0; i < 60; ++i) {
			minutesComboBox.addItem(Integer.toString(i));
		}
		return minutesComboBox;
	}

	private JButton makeRegisterButton() {
		registerButton = new JButton(resources.getString("button.register"));
		registerButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				registerButton_actionPerformed(e);
			}
		});
		return registerButton;
	}

	void registerButton_actionPerformed(ActionEvent e) {
		Date date = calendarDate.getDate();
		String sh = (String)hoursComboBox.getSelectedItem();
		String sm = (String)minutesComboBox.getSelectedItem();
		int hour   = Integer.parseInt(sh);
		int minute = Integer.parseInt(sm);
		Time time  = DateTimeUtils.toSQLTime(hour, minute, 0);
		String memo = memoTextField.getText();
		FixedSchedule newSchedule = new FixedSchedule(date, time, memo);
		if (fixedSchedule != null) {
			calendarDate.removeFixedSchedule(fixedSchedule);
		}
		calendarDate.addFixedSchedule(newSchedule);
		dispose();
	}
}
