/*
 * ScheduleTest.java
 */

package scheduler.tests;

import java.sql.Date;
import java.util.Calendar;
import junit.framework.TestCase;
import scheduler.util.DateTimeUtils;
import scheduler.domain.*;

public class ScheduleTest extends TestCase
{
	public ScheduleTest(String name) {
		super(name);
	}

	public void testFixedSchedule() {
		FixedSchedule schedule
			= new FixedSchedule(2002, 3, 4, 23, 45, "foo");
		assertEquals(2002, schedule.getYear());
		assertEquals(   3, schedule.getMonth());
		assertEquals(   4, schedule.getDay());
		assertEquals(  23, schedule.getHour());
		assertEquals(  45, schedule.getMinute());

		Content content = schedule.getContent();
		assertEquals("foo", content.getMemo());
		content.setMemo("bar");
		assertEquals("bar", content.getMemo());

		Date date1 = DateTimeUtils.toSQLDate(2002, 3, 4);
		assertTrue(schedule.isValid(date1));
		Date date2 = DateTimeUtils.toSQLDate(2002, 3, 5);
		assertTrue(!schedule.isValid(date2));
		assertEquals("23:45:00 bar (2002-03-04)", schedule.toString());
	}

	public void testWeeklySchedule() {
		WeeklySchedule schedule
			= new WeeklySchedule(Calendar.WEDNESDAY, 12, 34, "foo");
		assertEquals(Calendar.WEDNESDAY, schedule.getDayOfWeek());
		assertEquals(12, schedule.getHour());
		assertEquals(34, schedule.getMinute());

		Content content = schedule.getContent();
		assertEquals("foo", content.getMemo());
		content.setMemo("bar");
		assertEquals("bar", content.getMemo());

		Date date1 = DateTimeUtils.toSQLDate(2002, 4, 17);
		assertTrue(schedule.isValid(date1));
		Date date2 = DateTimeUtils.toSQLDate(2002, 4, 18);
		assertTrue(!schedule.isValid(date2));
		assertEquals("12:34:00 bar (Wed)", schedule.toString());

		schedule.setOpening(DateTimeUtils.toSQLDate(2002, 4, 20));
		assertTrue(!schedule.isValid(date1));
		schedule.setOpening(DateTimeUtils.toSQLDate(2002, 4, 15));
		assertTrue(schedule.isValid(date1));
		assertEquals("12:34:00 bar (Wed; 2002-04-15/)", schedule.toString());

		schedule.setClosing(DateTimeUtils.toSQLDate(2002, 4, 16));
		assertTrue(!schedule.isValid(date1));
		schedule.setClosing(DateTimeUtils.toSQLDate(2002, 4, 20));
		assertTrue(schedule.isValid(date1));
		assertEquals("12:34:00 bar (Wed; 2002-04-15/2002-04-20)",
				schedule.toString());

		schedule.setOpening(null);
		assertTrue(schedule.isValid(date1));
		assertEquals("12:34:00 bar (Wed; /2002-04-20)", schedule.toString());
	}
}
