/*
 * SchedulerDAOTest.java
 */

package scheduler.tests;

import java.io.*;
import java.util.*;
import junit.framework.TestCase;
import scheduler.util.DateTimeUtils;
import scheduler.domain.*;
import scheduler.dao.SchedulerDAOImpl;

public class SchedulerDAOTest extends TestCase
{
	static class TestDAO extends SchedulerDAOImpl {
		public void loadSchedules(Scheduler scheduler, BufferedReader in)
				throws IOException { super.loadSchedules(scheduler, in); }
		public void loadSchedule(Scheduler scheduler, List values)
			{ super.loadSchedule(scheduler, values); }
		public List toList(String line)
			{ return super.toList(line); }
		public FixedSchedule toFixedSchedule(List values)
			{ return super.toFixedSchedule(values); }
		public WeeklySchedule toWeeklySchedule(List values)
			{ return super.toWeeklySchedule(values); }
		public void saveFixedSchedules(PrintWriter out, SortedMap schedules)
			{ super.saveFixedSchedules(out, schedules); }
		public void saveWeeklySchedules(
				PrintWriter out, ScheduleList[] schedules)
			{ super.saveWeeklySchedules(out, schedules); }
		public String toLine(List values)
			{ return super.toLine(values); }
		public List toList(FixedSchedule schedule)
			{ return super.toList(schedule); }
		public List toList(WeeklySchedule schedule)
			{ return super.toList(schedule); }
	}

	private TestDAO dao = new TestDAO();

	public SchedulerDAOTest(String name) {
		super(name);
	}

	public void testToFixedSchedule() {
		List list = new ArrayList();
		list.add("F");
		list.add("12:34:00");
		list.add("memo");
		list.add("2002-06-09");
		FixedSchedule schedule = dao.toFixedSchedule(list);
		assertEquals(2002, schedule.getYear());
		assertEquals(   6, schedule.getMonth());
		assertEquals(   9, schedule.getDay());
		assertEquals(  12, schedule.getHour());
		assertEquals(  34, schedule.getMinute());
		assertEquals("memo", schedule.getContent().getMemo());
	}

	public void testToWeeklySchedule() {
		List list = new ArrayList();
		list.add("W");
		list.add("23:45:00");
		list.add("memo");
		list.add("2000-01-02");
		list.add("");
		list.add("7");
		WeeklySchedule schedule = dao.toWeeklySchedule(list);
		assertEquals(Calendar.SATURDAY, schedule.getDayOfWeek());
		assertEquals(23, schedule.getHour());
		assertEquals(45, schedule.getMinute());
		assertEquals("memo", schedule.getContent().getMemo());
		assertEquals(DateTimeUtils.toSQLDate(2000, 1, 2), schedule.getOpening());
		assertNull(schedule.getClosing());
	}

	public void testToList() {
		List list = dao.toList("a, b, c");
		assertEquals(3,   list.size());
		assertEquals("a", list.get(0));
		assertEquals("b", list.get(1));
		assertEquals("c", list.get(2));
	}

	public void testFixedScheduleToList() {
		FixedSchedule
		schedule = new FixedSchedule(2002, 6, 9, 12, 34, "memo");
		List list = dao.toList(schedule);
		assertEquals("[F, 12:34:00, memo, 2002-06-09]", list.toString());
	}

	public void testWeeklyScheduleToList() {
		WeeklySchedule
		schedule = new WeeklySchedule(Calendar.SUNDAY, 23, 45, "memo");
		schedule.setClosing(DateTimeUtils.toSQLDate(2002, 12, 31));
		List list = dao.toList(schedule);
		assertEquals("[W, 23:45:00, memo, , 2002-12-31, 1]", list.toString());
	}

	public void testToLine() {
		List list = new ArrayList();
		list.add("A");
		list.add("B");
		list.add("C");
		String line = dao.toLine(list);
		assertEquals("A, B, C", line.toString());
	}
}
