/*
 * SchedulerTest.java
 */

package scheduler.tests;

import java.sql.Date;
import java.util.*;
import junit.framework.TestCase;
import scheduler.util.DateTimeUtils;
import scheduler.domain.*;

public class SchedulerTest extends TestCase
{
	public SchedulerTest(String name) {
		super(name);
	}

	public void testFixedSchedules() {
		Scheduler scheduler = new Scheduler();
		assertEquals(0, scheduler.getFixedSchedules().size());

		// f[^̏B
		// addFixedSchedule() ̃eXgB
		FixedSchedule s1 = new FixedSchedule(2002, 5, 5,  9,  0, "V");
		scheduler.addFixedSchedule(s1);
		FixedSchedule s2 = new FixedSchedule(2002, 4, 8, 21, 10, "A");
		scheduler.addFixedSchedule(s2);
		FixedSchedule s3 = new FixedSchedule(2002, 4, 8, 20,  0, "d");
		scheduler.addFixedSchedule(s3);
//		fail(scheduler.toString());
		assertEquals(2, scheduler.getFixedSchedules().size());
		assertEquals(2, scheduler.getFixedSchedules(2002,  4, 8).size());
		assertEquals(1, scheduler.getFixedSchedules(2002,  5, 5).size());
		assertEquals(0, scheduler.getFixedSchedules(2003, 12, 3).size());

		// removeFixedSchedule() ̃eXgB
		scheduler.removeFixedSchedule(s3);
		assertEquals(1, scheduler.getFixedSchedules(2002, 4, 8).size());
		scheduler.removeFixedSchedule(s2);
		assertEquals(0, scheduler.getFixedSchedules(2002, 4, 8).size());

		// clearFixedSchedules() ̃eXgB
		scheduler.clearFixedSchedules();
		assertEquals(0, scheduler.getFixedSchedules().size());
	}

	public void testWeeklySchedules() {
		Scheduler scheduler = new Scheduler();
		assertEquals(7, scheduler.getWeeklySchedules().length);
		for (int i = Calendar.SUNDAY; i <= Calendar.SATURDAY; ++i) {
			assertEquals(0, scheduler.getWeeklySchedules(i).size());
		}

		// f[^̏B
		// addWeeklySchedule() ̃eXgB
		WeeklySchedule s1 = new WeeklySchedule(
				Calendar.TUESDAY, 10, 00, "ō");
		scheduler.addWeeklySchedule(s1);
		WeeklySchedule s2 = new WeeklySchedule(
				Calendar.FRIDAY, 13, 30, "񍐉");
		scheduler.addWeeklySchedule(s2);
		WeeklySchedule s3 = new WeeklySchedule(
				Calendar.FRIDAY, 18, 30, "׋");
		scheduler.addWeeklySchedule(s3);
//		fail(scheduler.toString());
		assertEquals(1, scheduler.getWeeklySchedules(Calendar.TUESDAY).size());
		assertEquals(2, scheduler.getWeeklySchedules(Calendar.FRIDAY).size());

		// removeWeeklySchedule() ̃eXgB
		scheduler.removeWeeklySchedule(s3);
		assertEquals(1, scheduler.getWeeklySchedules(Calendar.FRIDAY).size());

		// clearWeeklySchedules() ̃eXgB
		scheduler.clearWeeklySchedules();
		for (int i = Calendar.SUNDAY; i <= Calendar.SATURDAY; ++i) {
			assertEquals(0, scheduler.getWeeklySchedules(i).size());
		}
	}
}
